"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const vue_1 = require("vue");
const index_vue_1 = tslib_1.__importDefault(require("./index.vue"));
const messageInstance = new Map();
const initInstance = (props, container, appContext = null) => {
    const vnode = vue_1.h(index_vue_1.default, props);
    vnode.appContext = appContext;
    vue_1.render(vnode, container);
    console.log(container, container.firstElementChild);
    document.body.appendChild(container.firstElementChild);
    return vnode.component;
};
const showMessage = (options, appContext) => {
    const container = document.createElement('div');
    // Adding destruct method.
    // when transition leaves emitting `vanish` evt. so that we can do the clean job.
    options.onVanish = () => {
        // not sure if this causes mem leak, need proof to verify that.
        // maybe calling out like 1000 msg-box then close them all.
        vue_1.render(null, container);
        messageInstance.delete(vm); // Remove vm to avoid mem leak.
        // here we were suppose to call document.body.removeChild(container.firstElementChild)
        // but render(null, container) did that job for us. so that we do not call that directly
    };
    // options.onAction = (action: Action) => {
    //   const currentMsg = messageInstance.get(vm)!
    //   let resolve: Action | { value: string; action: Action }
    //   if (options.showInput) {
    //     resolve = { value: vm.inputValue, action }
    //   } else {
    //     resolve = action
    //   }
    //   if (options.callback) {
    //     options.callback(resolve, instance.proxy)
    //   } else {
    //     if (action === 'cancel' || action === 'close') {
    //       if (options.distinguishCancelAndClose && action !== 'cancel') {
    //         currentMsg.reject('close')
    //       } else {
    //         currentMsg.reject('cancel')
    //       }
    //     } else {
    //       currentMsg.resolve(resolve)
    //     }
    //   }
    // }
    const instance = initInstance(options, container, appContext);
    // This is how we use message box programmably.
    // Maybe consider releasing a template version?
    // get component instance like v2.
    const vm = instance.proxy;
    // for (const prop in options) {
    //   if (hasOwn(options, prop) && !hasOwn(vm.$props, prop)) {
    //     vm[prop as string] = options[prop]
    //   }
    // }
    // watch(
    //   () => vm.message,
    //   (newVal, oldVal) => {
    //     if (isVNode(newVal)) {
    //       // Override slots since message is vnode type.
    //       instance.slots.default = () => [newVal]
    //     } else if (isVNode(oldVal) && !isVNode(newVal)) {
    //       delete instance.slots.default
    //     }
    //   },
    //   {
    //     immediate: true,
    //   }
    // )
    // change visibility after everything is settled
    vm.visible = true;
    return vm;
};
function MessageBox(options, appContext = null) {
    // if (!isClient) return Promise.reject()
    // let callback
    // if (isString(options) || isVNode(options)) {
    //   options = {
    //     message: options,
    //   }
    // } else {
    //   callback = options.callback
    // }
    return new Promise((resolve, reject) => {
        const vm = showMessage(options, appContext);
        // collect this vm in order to handle upcoming events.
        messageInstance.set(vm, {
            options,
            // callback,
            resolve,
            reject,
        });
    });
}
const MESSAGE_BOX_VARIANTS = ['alert', 'confirm', 'prompt'];
const MESSAGE_BOX_DEFAULT_OPTS = {
    alert: { closeOnPressEscape: false, closeOnClickModal: false },
    confirm: { showCancelButton: true },
    prompt: { showCancelButton: true, showInput: true },
};
MESSAGE_BOX_VARIANTS.forEach((boxType) => {
    MessageBox[boxType] = messageBoxFactory(boxType);
});
function messageBoxFactory(boxType) {
    return (message, titleOrOpts, options, appContext) => {
        let title = titleOrOpts;
        return MessageBox(Object.assign({
            title,
            message,
            type: '',
            ...MESSAGE_BOX_DEFAULT_OPTS[boxType],
        }, options, {
            boxType,
        }), appContext);
    };
}
// console.log(MessageBox)
exports.default = MessageBox;
