"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.closeAll = void 0;
const tslib_1 = require("tslib");
const vue_1 = require("vue");
const index_vue_1 = tslib_1.__importDefault(require("./src/index.vue"));
const utils_1 = require("../utils");
const message_1 = require("./message");
let seed = 1;
let zIndex = 1000;
const instances = [];
const message = (options = {}, context) => {
    const appendTo = document.body;
    const container = document.createElement('div');
    zIndex++;
    let verticalOffset = options.offset || 0;
    instances.forEach(({ vm }) => {
        verticalOffset += (vm.el?.offsetHeight || 0) + 16;
    });
    verticalOffset += 16;
    const userOnClose = options.onClose;
    const id = `message_${seed++}`;
    const props = {
        zIndex: zIndex,
        duration: 2000,
        ...options,
        offset: verticalOffset,
        id,
        onClose: () => {
            close(id, userOnClose);
        },
    };
    const messageContent = props.message;
    const vm = vue_1.createVNode(index_vue_1.default, props, utils_1.isFunction(messageContent)
        ? { default: messageContent }
        : vue_1.isVNode(messageContent)
            ? { default: () => messageContent }
            : null);
    vm.props.onDestroy = () => {
        vue_1.render(null, container);
    };
    vue_1.render(vm, container);
    instances.push({ vm });
    appendTo.appendChild(container.firstElementChild);
    return {
        // instead of calling the onClose function directly, setting this value so that we can have the full lifecycle
        // for out component, so that all closing steps will not be skipped.
        close: () => (vm.component.proxy.visible = false),
    };
};
message_1.messageTypes.forEach((t) => {
    message[t] = (options = {}, appContext) => {
        if (utils_1.isString(options) || vue_1.isVNode(options)) {
            options = {
                message: options,
            };
        }
        return message({
            ...options,
            type: t,
        }, appContext);
    };
});
function close(id, userOnClose) {
    const idx = instances.findIndex(({ vm }) => id === vm?.props.id);
    if (idx === -1)
        return;
    const { vm } = instances[idx];
    if (!vm)
        return;
    userOnClose?.(vm);
    const removedHeight = vm.el.offsetHeight;
    instances.splice(idx, 1);
    const len = instances.length;
    if (len < 1)
        return;
    for (let i = idx; i < len; i++) {
        const pos = Number.parseInt(instances[i].vm.el.style['top'], 10) - removedHeight - 16;
        instances[i].vm.component.props.offset = pos;
    }
}
function closeAll() {
    for (let i = instances.length - 1; i >= 0; i--) {
        const instance = instances[i].vm.component;
        instance?.proxy?.close();
    }
}
exports.closeAll = closeAll;
message.closeAll = closeAll;
message._context = null;
exports.default = message;
