"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_1 = require("vue");
const shared_1 = require("@vue/shared");
const NAME = 'ShOnlyChild';
const OnlyChild = vue_1.defineComponent({
    name: NAME,
    emits: [],
    components: {},
    props: {},
    setup(props, { slots, attrs }) {
        return () => {
            const defaultSlot = slots.default?.(attrs);
            const firstLegitNode = findFirstLegitChild(defaultSlot);
            if (!firstLegitNode) {
                console.error(NAME, 'no valid child node found');
                return null;
            }
            // return withDirectives(cloneVNode(firstLegitNode!, attrs), [])
            return vue_1.cloneVNode(firstLegitNode, attrs);
        };
    },
});
function findFirstLegitChild(node) {
    if (!node)
        return null;
    const children = node;
    for (const child of children) {
        if (shared_1.isObject(child)) {
            switch (child.type) {
                case vue_1.Comment:
                    continue;
                case vue_1.Text:
                    return wrapTextContent(child);
                case 'svg':
                    return wrapTextContent(child);
                case vue_1.Fragment:
                    return findFirstLegitChild(child.children);
                default:
                    return child;
            }
        }
        return wrapTextContent(child);
    }
    return null;
}
function wrapTextContent(s) {
    return vue_1.h('span', { clasd: 'sh-only-child__content' }, s);
}
exports.default = OnlyChild;
